//**************************************************************************************************
//
// TimeUtils.h: interface for the CTimeUtils class.
//
// Description: Anything to do with time
//
// Created by: Keith Ditchburn 03/10/01
//
// Note: Singleton: call by using TIMER.
//
//**************************************************************************************************
#ifndef __TimeUtils_h
#define __TimeUtils_h

#pragma once

class CTimeUtils  
{
private:	
	void DebugString(char *text, ...);

	static CTimeUtils * _instance;	

	__int64 m_tps;				// freq of performance counter, if one exists
	double m_spt;				// 1/tps
	bool m_pert_enable;			// performance counter? else use timegettime 
	__int64 m_pert_start;		// Initialisation time performance-timer
	unsigned int m_mmt_start;	// Initialisation time timegettime

	// Variables used to smooth movement:
	float m_lastTickTime;
	float m_lerpValue;
protected:
	CTimeUtils();
public:
	void Pause(float numSeconds) const;
	float GetLerpValue() const;
	bool FrameMove(float timeOfOneTick);
	float GetTimeInSeconds() const;
	void Initialise();
	static void RemoveInstance();
	static CTimeUtils & Instance();
	
	~CTimeUtils();

};

#define TIMER CTimeUtils::Instance()

#define REMOVE_TIMER CTimeUtils::RemoveInstance()

#define CREATE_TIMER CTimeUtils::Instance();TIMER.Initialise()

#endif // #ifndef __TimeUtils_h
